==> connector-service-1.0.0-20191211.121047-103-sources.jar: com/bizvane/connectorservice/entity/icrm/RechargeCardResponseVO.java <==
package com.bizvane.connectorservice.entity.icrm;

import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;
import java.math.BigDecimal;

public class RechargeCardResponseVO implements Serializable {
    @ApiModelProperty(
            value = "储值卡自增id",
            name = "prepaid_card_id",
            required = true,
            example = ""
    )
    private String prepaid_card_id;


    @ApiModelProperty(
            value = "储值卡号",
            name = "prepaid_card_code",
            required = true,
            example = ""
    )
    private String prepaid_card_code;


    @ApiModelProperty(
            value = "状态0:正常，1停用 2挂失",
            name = "status",
            required = true,
            example = ""
    )
    private String status;


    @ApiModelProperty(
            value = "储值卡类别代码",
            name = "category_code",
            required = true,
            example = ""
    )
    private String category_code;
    @ApiModelProperty(
            value = "姓名",
            name = "name",
            required = false,
            example = ""
    )
    private String name;

    @ApiModelProperty(
            value = "手机号",
            name = "tel",
            required = false,
            example = ""
    )
    private String tel;
    @ApiModelProperty(
            value = "顾客代码",
            name = "customer_code",
            required = false,
            example = ""
    )
    private String customer_code;
    @ApiModelProperty(
            value = "渠道代码",
            name = "org_code",
            required = false,
            example = ""
    )
    private String org_code;
    @ApiModelProperty(
            value = "店铺代码",
            name = "shop_code",
            required = true,
            example = ""
    )
    private String shop_code;

    @ApiModelProperty(
            value = "到期时间",
            name = "last_time",
            required = true,
            example = ""
    )
    private String last_time;
    @ApiModelProperty(
            value = "剩余金额",
            name = "surplus_money",
            required = true,
            example = ""
    )
    private BigDecimal surplus_money;
    @ApiModelProperty(
            value = "消费金额",
            name = "consume_money",
            required = true,
            example = ""
    )
    private BigDecimal consume_money;
    @ApiModelProperty(
            value = "累积充值金额",
            name = "count_money",
            required = true,
            example = ""
    )
    private BigDecimal count_money;
    @ApiModelProperty(
            value = "累积消费金额",
            name = "count_consume_money",
            required = true,
            example = ""
    )
    private BigDecimal count_consume_money;

    @ApiModelProperty(
            value = "积分",
            name = "integral",
            required = true,
            example = ""
    )
    private Integer integral;
    @ApiModelProperty(
            value = "礼券 0-不启用 1-现金 2折扣",
            name = "gift_coupon",
            required = true,
            example = ""
    )

    private String gift_coupon;

    @ApiModelProperty(
            value = "启用时间",
            name = "is_start_time",
            required = true,
            example = ""
    )
    private String is_start_time;

    private  String is_stop_time;
    private String is_loss_time;

    private String last_consume_time;
    private BigDecimal last_consume_money;
    private String last_prepaid_time;
    private BigDecimal last_prepaid_money;
    private String remark;
    private String lastchanged;

    @ApiModelProperty(
            value = "充值折扣",
            name = "recharge_rebate",
            required = false,
            example = ""
    )
    private String recharge_rebate;

    @ApiModelProperty(
            value = "会员卡号",
            name = "vip_code",
            required = false,
            example = ""
    )
    private String vip_code;

    @ApiModelProperty(
            value = "适用范围 0-全部 1-按组织机构 2-按终端",
            name = "application_scope",
            required = false,
            example = ""
    )
    private Integer application_scope;
    @ApiModelProperty(
            value = "适用商品 0-全部 1 其它",
            name = "application_goods_control",
            required = false,
            example = ""
    )
    private Integer application_goods_control;
    @ApiModelProperty(
            value = "适用商品设置 0-商品级 1品牌",
            name = "application_goods_set",
            required = false,
            example = ""
    )
    private Integer application_goods_set;

    @ApiModelProperty(
            value = "充值范围 0-全部 1-同投放终端 2-同适用范围 3-按组织机构 4-按终端",
            name = "recharge_scope",
            required = false,
            example = ""
    )
    private Integer recharge_scope;

    @ApiModelProperty(
            value = "适用限制  0 不允许外卡叠加适用 1 允许外卡叠加适用",
            name = "use_limit",
            required = false,
            example = ""
    )
    private Integer use_limit;
    @ApiModelProperty(
            value = "限原价商品使用 0 不限 1 限原价商品适用",
            name = "original_price_use_control",
            required = false,
            example = ""
    )
    private Integer original_price_use_control;

    @ApiModelProperty(
            value = "最低商品折扣控制 : 限原价商品使用不勾选时最低商品折扣可编辑   0-> 1->=",
            name = "min_rebate_control",
            required = false,
            example = ""
    )
    private Integer min_rebate_control;
    @ApiModelProperty(
            value = "可消费的最低商品折扣值",
            name = "min_rebate",
            required = false,
            example = ""
    )
    private Integer min_rebate;
    @ApiModelProperty(
            value = "卡唯一标识",
            name = "vip_code_unique",
            required = false,
            example = ""
    )
    private String vip_code_unique;
    @ApiModelProperty(
            value = "密码",
            name = "password",
            required = false,
            example = ""
    )
    private String password;
    @ApiModelProperty(
            value = "累计充值实付金额",
            name = "total_pay_money",
            required = false,
            example = ""
    )
    private BigDecimal total_pay_money;

    @ApiModelProperty(
            value = "实际售价控制方式 0不控制 1实际售价=建议售价 2实际售价>=建议售价 3实际售价<=建议售价",
            name = "real_price_control",
            required = false,
            example = ""
    )
    private Integer real_price_control;
  //  private String application_scope;//适用店铺，渠道
 //   private String recharge_scope;//适用充值店铺


    public String getPrepaid_card_id() {
        return prepaid_card_id;
    }

    public void setPrepaid_card_id(String prepaid_card_id) {
        this.prepaid_card_id = prepaid_card_id;
    }

    public String getPrepaid_card_code() {
        return prepaid_card_code;
    }

    public void setPrepaid_card_code(String prepaid_card_code) {
        this.prepaid_card_code = prepaid_card_code;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getCategory_code() {
        return category_code;
    }

    public void setCategory_code(String category_code) {
        this.category_code = category_code;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getTel() {
        return tel;
    }

    public void setTel(String tel) {
        this.tel = tel;
    }

    public String getCustomer_code() {
        return customer_code;
    }

    public void setCustomer_code(String customer_code) {
        this.customer_code = customer_code;
    }

    public String getOrg_code() {
        return org_code;
    }

    public void setOrg_code(String org_code) {
        this.org_code = org_code;
    }

    public String getShop_code() {
        return shop_code;
    }

    public void setShop_code(String shop_code) {
        this.shop_code = shop_code;
    }

    public String getLast_time() {
        return last_time;
    }

    public void setLast_time(String last_time) {
        this.last_time = last_time;
    }

    public BigDecimal getSurplus_money() {
        return surplus_money;
    }

    public void setSurplus_money(BigDecimal surplus_money) {
        this.surplus_money = surplus_money;
    }

    public BigDecimal getConsume_money() {
        return consume_money;
    }

    public void setConsume_money(BigDecimal consume_money) {
        this.consume_money = consume_money;
    }

    public BigDecimal getCount_money() {
        return count_money;
    }

    public void setCount_money(BigDecimal count_money) {
        this.count_money = count_money;
    }

    public BigDecimal getCount_consume_money() {
        return count_consume_money;
    }

    public void setCount_consume_money(BigDecimal count_consume_money) {
        this.count_consume_money = count_consume_money;
    }

    public Integer getIntegral() {
        return integral;
    }

    public void setIntegral(Integer integral) {
        this.integral = integral;
    }

    public String getGift_coupon() {
        return gift_coupon;
    }

    public void setGift_coupon(String gift_coupon) {
        this.gift_coupon = gift_coupon;
    }

    public String getIs_start_time() {
        return is_start_time;
    }

    public void setIs_start_time(String is_start_time) {
        this.is_start_time = is_start_time;
    }

    public String getIs_stop_time() {
        return is_stop_time;
    }

    public void setIs_stop_time(String is_stop_time) {
        this.is_stop_time = is_stop_time;
    }

    public String getIs_loss_time() {
        return is_loss_time;
    }

    public void setIs_loss_time(String is_loss_time) {
        this.is_loss_time = is_loss_time;
    }

    public String getLast_consume_time() {
        return last_consume_time;
    }

    public void setLast_consume_time(String last_consume_time) {
        this.last_consume_time = last_consume_time;
    }

    public BigDecimal getLast_consume_money() {
        return last_consume_money;
    }

    public void setLast_consume_money(BigDecimal last_consume_money) {
        this.last_consume_money = last_consume_money;
    }

    public String getLast_prepaid_time() {
        return last_prepaid_time;
    }

    public void setLast_prepaid_time(String last_prepaid_time) {
        this.last_prepaid_time = last_prepaid_time;
    }

    public BigDecimal getLast_prepaid_money() {
        return last_prepaid_money;
    }

    public void setLast_prepaid_money(BigDecimal last_prepaid_money) {
        this.last_prepaid_money = last_prepaid_money;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public String getLastchanged() {
        return lastchanged;
    }

    public void setLastchanged(String lastchanged) {
        this.lastchanged = lastchanged;
    }

    public String getRecharge_rebate() {
        return recharge_rebate;
    }

    public void setRecharge_rebate(String recharge_rebate) {
        this.recharge_rebate = recharge_rebate;
    }

    public String getVip_code() {
        return vip_code;
    }

    public void setVip_code(String vip_code) {
        this.vip_code = vip_code;
    }

    public Integer getApplication_scope() {
        return application_scope;
    }

    public void setApplication_scope(Integer application_scope) {
        this.application_scope = application_scope;
    }

    public Integer getApplication_goods_control() {
        return application_goods_control;
    }

    public void setApplication_goods_control(Integer application_goods_control) {
        this.application_goods_control = application_goods_control;
    }

    public Integer getApplication_goods_set() {
        return application_goods_set;
    }

    public void setApplication_goods_set(Integer application_goods_set) {
        this.application_goods_set = application_goods_set;
    }

    public Integer getRecharge_scope() {
        return recharge_scope;
    }

    public void setRecharge_scope(Integer recharge_scope) {
        this.recharge_scope = recharge_scope;
    }

    public Integer getUse_limit() {
        return use_limit;
    }

    public void setUse_limit(Integer use_limit) {
        this.use_limit = use_limit;
    }

    public Integer getOriginal_price_use_control() {
        return original_price_use_control;
    }

    public void setOriginal_price_use_control(Integer original_price_use_control) {
        this.original_price_use_control = original_price_use_control;
    }

    public Integer getMin_rebate_control() {
        return min_rebate_control;
    }

    public void setMin_rebate_control(Integer min_rebate_control) {
        this.min_rebate_control = min_rebate_control;
    }

    public Integer getMin_rebate() {
        return min_rebate;
    }

    public void setMin_rebate(Integer min_rebate) {
        this.min_rebate = min_rebate;
    }

    public String getVip_code_unique() {
        return vip_code_unique;
    }

    public void setVip_code_unique(String vip_code_unique) {
        this.vip_code_unique = vip_code_unique;
    }

    public String getPassword() {
        return password;
    }

    public void setPassword(String password) {
        this.password = password;
    }

    public BigDecimal getTotal_pay_money() {
        return total_pay_money;
    }

    public void setTotal_pay_money(BigDecimal total_pay_money) {
        this.total_pay_money = total_pay_money;
    }

    public Integer getReal_price_control() {
        return real_price_control;
    }

    public void setReal_price_control(Integer real_price_control) {
        this.real_price_control = real_price_control;
    }
}

==> connector-service-1.0.0-20200310.023930-145-sources.jar: com/bizvane/connectorservice/entity/icrm/RechargeCardResponseVO.java <==
package com.bizvane.connectorservice.entity.icrm;

import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;
import java.math.BigDecimal;

public class RechargeCardResponseVO implements Serializable {
    @ApiModelProperty(
            value = "储值卡自增id",
            name = "prepaid_card_id",
            required = true,
            example = ""
    )
    private String prepaid_card_id;


    @ApiModelProperty(
            value = "储值卡号",
            name = "prepaid_card_code",
            required = true,
            example = ""
    )
    private String prepaid_card_code;


    @ApiModelProperty(
            value = "状态0:正常，1停用 2挂失",
            name = "status",
            required = true,
            example = ""
    )
    private String status;


    @ApiModelProperty(
            value = "储值卡类别代码",
            name = "category_code",
            required = true,
            example = ""
    )
    private String category_code;
    @ApiModelProperty(
            value = "姓名",
            name = "name",
            required = false,
            example = ""
    )
    private String name;

    @ApiModelProperty(
            value = "手机号",
            name = "tel",
            required = false,
            example = ""
    )
    private String tel;
    @ApiModelProperty(
            value = "顾客代码",
            name = "customer_code",
            required = false,
            example = ""
    )
    private String customer_code;
    @ApiModelProperty(
            value = "渠道代码",
            name = "org_code",
            required = false,
            example = ""
    )
    private String org_code;
    @ApiModelProperty(
            value = "店铺代码",
            name = "shop_code",
            required = true,
            example = ""
    )
    private String shop_code;

    @ApiModelProperty(
            value = "到期时间",
            name = "last_time",
            required = true,
            example = ""
    )
    private String last_time;
    @ApiModelProperty(
            value = "剩余金额",
            name = "surplus_money",
            required = true,
            example = ""
    )
    private BigDecimal surplus_money;
    @ApiModelProperty(
            value = "消费金额",
            name = "consume_money",
            required = true,
            example = ""
    )
    private BigDecimal consume_money;
    @ApiModelProperty(
            value = "累积充值金额",
            name = "count_money",
            required = true,
            example = ""
    )
    private BigDecimal count_money;
    @ApiModelProperty(
            value = "累积消费金额",
            name = "count_consume_money",
            required = true,
            example = ""
    )
    private BigDecimal count_consume_money;

    @ApiModelProperty(
            value = "积分",
            name = "integral",
            required = true,
            example = ""
    )
    private Integer integral;
    @ApiModelProperty(
            value = "礼券 0-不启用 1-现金 2折扣",
            name = "gift_coupon",
            required = true,
            example = ""
    )

    private String gift_coupon;

    @ApiModelProperty(
            value = "启用时间",
            name = "is_start_time",
            required = true,
            example = ""
    )
    private String is_start_time;

    private  String is_stop_time;
    private String is_loss_time;

    private String last_consume_time;
    private BigDecimal last_consume_money;
    private String last_prepaid_time;
    private BigDecimal last_prepaid_money;
    private String remark;
    private String lastchanged;

    @ApiModelProperty(
            value = "充值折扣",
            name = "recharge_rebate",
            required = false,
            example = ""
    )
    private String recharge_rebate;

    @ApiModelProperty(
            value = "会员卡号",
            name = "vip_code",
            required = false,
            example = ""
    )
    private String vip_code;

    @ApiModelProperty(
            value = "适用范围 0-全部 1-按组织机构 2-按终端",
            name = "application_scope",
            required = false,
            example = ""
    )
    private Integer application_scope;
    @ApiModelProperty(
            value = "适用商品 0-全部 1 其它",
            name = "application_goods_control",
            required = false,
            example = ""
    )
    private Integer application_goods_control;
    @ApiModelProperty(
            value = "适用商品设置 0-商品级 1品牌",
            name = "application_goods_set",
            required = false,
            example = ""
    )
    private Integer application_goods_set;

    @ApiModelProperty(
            value = "充值范围 0-全部 1-同投放终端 2-同适用范围 3-按组织机构 4-按终端",
            name = "recharge_scope",
            required = false,
            example = ""
    )
    private Integer recharge_scope;

    @ApiModelProperty(
            value = "适用限制  0 不允许外卡叠加适用 1 允许外卡叠加适用",
            name = "use_limit",
            required = false,
            example = ""
    )
    private Integer use_limit;
    @ApiModelProperty(
            value = "限原价商品使用 0 不限 1 限原价商品适用",
            name = "original_price_use_control",
            required = false,
            example = ""
    )
    private Integer original_price_use_control;

    @ApiModelProperty(
            value = "最低商品折扣控制 : 限原价商品使用不勾选时最低商品折扣可编辑   0-> 1->=",
            name = "min_rebate_control",
            required = false,
            example = ""
    )
    private Integer min_rebate_control;
    @ApiModelProperty(
            value = "可消费的最低商品折扣值",
            name = "min_rebate",
            required = false,
            example = ""
    )
    private BigDecimal min_rebate;
    @ApiModelProperty(
            value = "卡唯一标识",
            name = "vip_code_unique",
            required = false,
            example = ""
    )
    private String vip_code_unique;
    @ApiModelProperty(
            value = "密码",
            name = "password",
            required = false,
            example = ""
    )
    private String password;
    @ApiModelProperty(
            value = "累计充值实付金额",
            name = "total_pay_money",
            required = false,
            example = ""
    )
    private BigDecimal total_pay_money;

    @ApiModelProperty(
            value = "实际售价控制方式 0不控制 1实际售价=建议售价 2实际售价>=建议售价 3实际售价<=建议售价",
            name = "real_price_control",
            required = false,
            example = ""
    )
    private Integer real_price_control;
  //  private String application_scope;//适用店铺，渠道
 //   private String recharge_scope;//适用充值店铺


    public String getPrepaid_card_id() {
        return prepaid_card_id;
    }

    public void setPrepaid_card_id(String prepaid_card_id) {
        this.prepaid_card_id = prepaid_card_id;
    }

    public String getPrepaid_card_code() {
        return prepaid_card_code;
    }

    public void setPrepaid_card_code(String prepaid_card_code) {
        this.prepaid_card_code = prepaid_card_code;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getCategory_code() {
        return category_code;
    }

    public void setCategory_code(String category_code) {
        this.category_code = category_code;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getTel() {
        return tel;
    }

    public void setTel(String tel) {
        this.tel = tel;
    }

    public String getCustomer_code() {
        return customer_code;
    }

    public void setCustomer_code(String customer_code) {
        this.customer_code = customer_code;
    }

    public String getOrg_code() {
        return org_code;
    }

    public void setOrg_code(String org_code) {
        this.org_code = org_code;
    }

    public String getShop_code() {
        return shop_code;
    }

    public void setShop_code(String shop_code) {
        this.shop_code = shop_code;
    }

    public String getLast_time() {
        return last_time;
    }

    public void setLast_time(String last_time) {
        this.last_time = last_time;
    }

    public BigDecimal getSurplus_money() {
        return surplus_money;
    }

    public void setSurplus_money(BigDecimal surplus_money) {
        this.surplus_money = surplus_money;
    }

    public BigDecimal getConsume_money() {
        return consume_money;
    }

    public void setConsume_money(BigDecimal consume_money) {
        this.consume_money = consume_money;
    }

    public BigDecimal getCount_money() {
        return count_money;
    }

    public void setCount_money(BigDecimal count_money) {
        this.count_money = count_money;
    }

    public BigDecimal getCount_consume_money() {
        return count_consume_money;
    }

    public void setCount_consume_money(BigDecimal count_consume_money) {
        this.count_consume_money = count_consume_money;
    }

    public Integer getIntegral() {
        return integral;
    }

    public void setIntegral(Integer integral) {
        this.integral = integral;
    }

    public String getGift_coupon() {
        return gift_coupon;
    }

    public void setGift_coupon(String gift_coupon) {
        this.gift_coupon = gift_coupon;
    }

    public String getIs_start_time() {
        return is_start_time;
    }

    public void setIs_start_time(String is_start_time) {
        this.is_start_time = is_start_time;
    }

    public String getIs_stop_time() {
        return is_stop_time;
    }

    public void setIs_stop_time(String is_stop_time) {
        this.is_stop_time = is_stop_time;
    }

    public String getIs_loss_time() {
        return is_loss_time;
    }

    public void setIs_loss_time(String is_loss_time) {
        this.is_loss_time = is_loss_time;
    }

    public String getLast_consume_time() {
        return last_consume_time;
    }

    public void setLast_consume_time(String last_consume_time) {
        this.last_consume_time = last_consume_time;
    }

    public BigDecimal getLast_consume_money() {
        return last_consume_money;
    }

    public void setLast_consume_money(BigDecimal last_consume_money) {
        this.last_consume_money = last_consume_money;
    }

    public String getLast_prepaid_time() {
        return last_prepaid_time;
    }

    public void setLast_prepaid_time(String last_prepaid_time) {
        this.last_prepaid_time = last_prepaid_time;
    }

    public BigDecimal getLast_prepaid_money() {
        return last_prepaid_money;
    }

    public void setLast_prepaid_money(BigDecimal last_prepaid_money) {
        this.last_prepaid_money = last_prepaid_money;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public String getLastchanged() {
        return lastchanged;
    }

    public void setLastchanged(String lastchanged) {
        this.lastchanged = lastchanged;
    }

    public String getRecharge_rebate() {
        return recharge_rebate;
    }

    public void setRecharge_rebate(String recharge_rebate) {
        this.recharge_rebate = recharge_rebate;
    }

    public String getVip_code() {
        return vip_code;
    }

    public void setVip_code(String vip_code) {
        this.vip_code = vip_code;
    }

    public Integer getApplication_scope() {
        return application_scope;
    }

    public void setApplication_scope(Integer application_scope) {
        this.application_scope = application_scope;
    }

    public Integer getApplication_goods_control() {
        return application_goods_control;
    }

    public void setApplication_goods_control(Integer application_goods_control) {
        this.application_goods_control = application_goods_control;
    }

    public Integer getApplication_goods_set() {
        return application_goods_set;
    }

    public void setApplication_goods_set(Integer application_goods_set) {
        this.application_goods_set = application_goods_set;
    }

    public Integer getRecharge_scope() {
        return recharge_scope;
    }

    public void setRecharge_scope(Integer recharge_scope) {
        this.recharge_scope = recharge_scope;
    }

    public Integer getUse_limit() {
        return use_limit;
    }

    public void setUse_limit(Integer use_limit) {
        this.use_limit = use_limit;
    }

    public Integer getOriginal_price_use_control() {
        return original_price_use_control;
    }

    public void setOriginal_price_use_control(Integer original_price_use_control) {
        this.original_price_use_control = original_price_use_control;
    }

    public Integer getMin_rebate_control() {
        return min_rebate_control;
    }

    public void setMin_rebate_control(Integer min_rebate_control) {
        this.min_rebate_control = min_rebate_control;
    }

    public BigDecimal getMin_rebate() {
        return min_rebate;
    }

    public void setMin_rebate(BigDecimal min_rebate) {
        this.min_rebate = min_rebate;
    }

    public String getVip_code_unique() {
        return vip_code_unique;
    }

    public void setVip_code_unique(String vip_code_unique) {
        this.vip_code_unique = vip_code_unique;
    }

    public String getPassword() {
        return password;
    }

    public void setPassword(String password) {
        this.password = password;
    }

    public BigDecimal getTotal_pay_money() {
        return total_pay_money;
    }

    public void setTotal_pay_money(BigDecimal total_pay_money) {
        this.total_pay_money = total_pay_money;
    }

    public Integer getReal_price_control() {
        return real_price_control;
    }

    public void setReal_price_control(Integer real_price_control) {
        this.real_price_control = real_price_control;
    }
}
